@@ -19,17 +19,34 @@
 A polyhedral library based on isl
 """
 
-from .geometry import GeometricObject, Point, Vector
-from .linexprs import LinExpr, Symbol, symbols, Dummy, Rational
-from .polyhedra import Polyhedron, Lt, Le, Eq, Ne, Ge, Gt, Ne, Empty, Universe
-from .domains import Domain, And, Or, Not
 from ._version import __version__
+from .domains import And, Domain, Not, Or
+from .geometry import GeometricObject, Point, Vector
+from .linexprs import Dummy, LinExpr, Rational, Symbol, symbols
+from .polyhedra import Empty, Eq, Ge, Gt, Le, Lt, Ne, Polyhedron, Universe
 
 
 __all__ = [
-    'LinExpr', 'Symbol', 'symbols', 'Dummy', 'Rational',
-    'GeometricObject', 'Point', 'Vector',
-    'Polyhedron', 'Lt', 'Le', 'Eq', 'Ne', 'Ge', 'Gt', 'Empty', 'Universe',
-    'Domain', 'And', 'Or', 'Not',
     '__version__',
+    'And',
+    'Domain',
+    'Dummy',
+    'Empty',
+    'Eq',
+    'Ge',
+    'GeometricObject',
+    'Gt',
+    'Le',
+    'LinExpr',
+    'Lt',
+    'Ne',
+    'Not',
+    'Or',
+    'Point',
+    'Polyhedron',
+    'Rational',
+    'Symbol',
+    'symbols',
+    'Universe',
+    'Vector',
 ]
